==> aws-solutions-constructs.aws-eventbridge-sns-1.158.0.tar.gz: aws-solutions-constructs.aws-eventbridge-sns-1.158.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-solutions-constructs.aws-eventbridge-sns",
    "version": "1.158.0",
    "description": "CDK Constructs for deploying AWS Events Rule that invokes AWS SNS",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_constructs.aws_eventbridge_sns",
        "aws_solutions_constructs.aws_eventbridge_sns._jsii"
    ],
    "package_data": {
        "aws_solutions_constructs.aws_eventbridge_sns._jsii": [
            "aws-eventbridge-sns@1.158.0.jsii.tgz"
        ],
        "aws_solutions_constructs.aws_eventbridge_sns": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk.aws-events==1.158.0",
        "aws-cdk.aws-iam==1.158.0",
        "aws-cdk.aws-kms==1.158.0",
        "aws-cdk.aws-sns==1.158.0",
        "aws-cdk.core==1.158.0",
        "aws-solutions-constructs.core==1.158.0",
        "constructs>=3.2.0, <4.0.0",
        "jsii>=1.62.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> aws-solutions-constructs.aws-eventbridge-sns-1.159.0.tar.gz: aws-solutions-constructs.aws-eventbridge-sns-1.159.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-solutions-constructs.aws-eventbridge-sns",
    "version": "1.159.0",
    "description": "CDK Constructs for deploying AWS Events Rule that invokes AWS SNS",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_constructs.aws_eventbridge_sns",
        "aws_solutions_constructs.aws_eventbridge_sns._jsii"
    ],
    "package_data": {
        "aws_solutions_constructs.aws_eventbridge_sns._jsii": [
            "aws-eventbridge-sns@1.159.0.jsii.tgz"
        ],
        "aws_solutions_constructs.aws_eventbridge_sns": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk.aws-events==1.159.0",
        "aws-cdk.aws-iam==1.159.0",
        "aws-cdk.aws-kms==1.159.0",
        "aws-cdk.aws-sns==1.159.0",
        "aws-cdk.core==1.159.0",
        "aws-solutions-constructs.core==1.159.0",
        "constructs>=3.2.0, <4.0.0",
        "jsii>=1.63.2, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
